@@ -1,6 +1,7 @@
-/* Copyright (C) 2015-2022 Ben Collins <bcollins@maclara-llc.com>
+/* Copyright (C) 2015-2023 Ben Collins <bcollins@maclara-llc.com>
    This file is part of the JWT C Library
 
+   SPDX-License-Identifier:  MPL-2.0
    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -15,6 +16,7 @@
 #include <openssl/buffer.h>
 #include <openssl/pem.h>
 #include <openssl/bn.h>
+#include <openssl/rsa.h>
 
 #include <jwt.h>
 
@@ -57,7 +59,7 @@ int jwt_sign_sha_hmac(jwt_t *jwt, char **out, unsigned int *len,
 	const EVP_MD *alg;
 
 	switch (jwt->alg) {
-        /* HMAC */
+	/* HMAC */
 	case JWT_ALG_HS256:
 		alg = EVP_sha256();
 		break;
@@ -141,7 +143,7 @@ int jwt_verify_sha_hmac(jwt_t *jwt, const char *head, unsigned int head_len, con
 	jwt_base64uri_encode(buf);
 
 	/* And now... */
-	ret = strcmp(buf, sig) ? EINVAL : 0;
+	ret = jwt_strcmp(buf, sig) ? EINVAL : 0;
 
 jwt_verify_hmac_done:
 	BIO_free_all(b64);
@@ -241,7 +243,7 @@ int jwt_sign_sha_pem(jwt_t *jwt, char **out, unsigned int *len,
 	if (EVP_DigestSignInit(mdctx, &pkey_ctx, alg, NULL, pkey) != 1)
 		SIGN_ERROR(EINVAL);
 
-	if (padding > 0 && (0 > EVP_PKEY_CTX_set_rsa_padding(pkey_ctx, padding)))
+	if (padding > 0 && EVP_PKEY_CTX_set_rsa_padding(pkey_ctx, padding) < 0)
 		SIGN_ERROR(EINVAL);
 
 	/* Call update with the message */
@@ -360,8 +362,8 @@ int jwt_verify_sha_pem(jwt_t *jwt, const char *head, unsigned int head_len, cons
 		type = EVP_PKEY_RSA;
 		break;
 
-        /* RSA-PSS */
-        case JWT_ALG_PS256:
+	/* RSA-PSS */
+	case JWT_ALG_PS256:
 		alg = EVP_sha256();
 		type = EVP_PKEY_RSA_PSS;
 		padding = RSA_PKCS1_PSS_PADDING;
@@ -465,7 +467,7 @@ int jwt_verify_sha_pem(jwt_t *jwt, const char *head, unsigned int head_len, cons
 	if (EVP_DigestVerifyInit(mdctx, &pkey_ctx, alg, NULL, pkey) != 1)
 		VERIFY_ERROR(EINVAL);
 
-	if (padding > 0 && (0 > EVP_PKEY_CTX_set_rsa_padding(pkey_ctx, padding)))
+	if (padding > 0 && EVP_PKEY_CTX_set_rsa_padding(pkey_ctx, padding) < 0)
 		VERIFY_ERROR(EINVAL);
 
 	/* Call update with the message */
